==> app-roku-v1.2.0.zip: locale/es_ES/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>Usuario</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Contraseña</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Presiona Regresar para acceder al menú</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>Todos los canales</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Canales</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Perfil</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Películas y Series</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Salir de la aplicación</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>¿Deseas salir de la aplicación?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Salir</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancelar</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>A continuación</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Ahora</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>¡Contraseña no válida!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Error al cargar contenido</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>No fue posible cargar, inténtalo de nuevo más tarde.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Cerrar sesión</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Bienvenido</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Selecciona el dominio</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>Debes seleccionar un proveedor antes de continuar</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Busca tu proveedor y selecciónalo para continuar.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Introduce tu usuario</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Introduce tu contraseña</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Confirmación de correo electrónico</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>Para acceder al nuevo contenido de películas, por favor, introduce tu correo electrónico y confirma a través del enlace enviado.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Enviar correo</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Espera</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>No fue posible cargar los contenidos, intenta de nuevo más tarde.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Intentar de nuevo</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Ver</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duración</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Temporada</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>¡Buena película!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>La compra de medios</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>se completó con éxito! Espera un momento.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>No fue posible realizar la compra</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>¡no se completó!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Detalles</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Buscar</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Regresar</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Entrar</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Selecciona tu proveedor de internet</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Próximo</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>¡Usuario autenticado exitosamente!</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Usuario bloqueado.</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Credenciales de acceso no válidas.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Se alcanzó el máximo de sesiones.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Error inesperado, contacta a tu proveedor de Internet.</translation>
  </message>
</context>
</TS>

==> app-roku-v1.3.0.zip: locale/es_ES/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>Usuario</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Contraseña</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Presiona Regresar para acceder al menú</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>Todos los canales</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Canales</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Perfil</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Películas y Series</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Salir de la aplicación</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>¿Deseas salir de la aplicación?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Salir</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancelar</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>A continuación</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Ahora</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>¡Contraseña no válida!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Error al cargar contenido</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>No fue posible cargar, inténtalo de nuevo más tarde.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Cerrar sesión</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Bienvenido</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Selecciona el dominio</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>Debes seleccionar un proveedor antes de continuar</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Busca tu proveedor y selecciónalo para continuar.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Introduce tu usuario</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Introduce tu contraseña</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Confirmación de correo electrónico</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>Para acceder al nuevo contenido de películas, por favor, introduce tu correo electrónico y confirma a través del enlace enviado.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Enviar correo</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Espera</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>No fue posible cargar los contenidos, intenta de nuevo más tarde.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Intentar de nuevo</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Ver</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duración</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Temporada</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>¡Buena película!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>La compra de medios</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>se completó con éxito! Espera un momento.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>No fue posible realizar la compra</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>¡no se completó!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Detalles</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Buscar</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Regresar</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Entrar</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Selecciona tu proveedor de internet</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Próximo</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>¡Usuario autenticado exitosamente!</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Usuario bloqueado.</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Credenciales de acceso no válidas.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Se alcanzó el máximo de sesiones.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Error inesperado, contacta a tu proveedor de Internet.</translation>
  </message>
  <message>
    <source>Senha alterada com sucesso.</source>
    <translation>Contraseña cambiada con éxito.</translation>
  </message>
  <message>
    <source>As senhas não conferem</source>
    <translation>Las contraseñas no coinciden</translation>
  </message>
  <message>
    <source>Erro</source>
    <translation>Error</translation>
  </message>
  <message>
    <source>Sucesso</source>
    <translation>Éxito</translation>
  </message>
  <message>
    <source>Alterar senha para conteúdo adulto</source>
    <translation>Cambiar contraseña para contenido adulto</translation>
  </message>
  <message>
    <source>Conteudo adulto</source>
    <translation>Contenido adulto</translation>
  </message>
  <message>
    <source>Confirme a senha</source>
    <translation>Confirme la contraseña</translation>
  </message>
  <message>
  <source>Continuar</source>
<translation>Continuar</translation>
</message>
<message>
<source>Cancelar</source>
<translation>Cancelar</translation>
</message>
</context>
</TS>
